[−][src]Crate coveralls_api
Structs
| BranchData | Representation of branch data |
| CoverallsReport | Coveralls report struct for more details: https://coveralls.zendesk.com/hc/en-us/articles/201350799-API-Reference |
| GitInfo | |
| Head | |
| Remote | |
| Service | Service's are used for CI integration. Coveralls current supports |
| Source | Struct representing source files and the coverage for coveralls |
Enums
| CiService | Continuous Integration services and the string identifiers coveralls.io uses to present them. |
| Identity | Repo tokens are alternatives to Services and involve a secret token on coveralls |
| UploadStatus | Reports the status of a coveralls report upload. |