[−][src]Struct coveralls_api::Service
Service's are used for CI integration. Coveralls current supports
- travis ci
- travis pro
- circleCI
- Semaphore
- JenkinsCI
- Codeship
Fields
name: CiServiceName of the CiService
job_id: Option<String>Job ID
number: Option<String>Optional service_number
build_url: Option<String>Optional service_build_url
branch: Option<String>Optional service_branch
pull_request: Option<String>Optional service_pull_request
Methods
impl Service[src]
pub fn from_env() -> Option<Self>[src]
pub fn from_ci(ci: CiService) -> Option<Self>[src]
pub fn get_travis_env() -> Self[src]
Gets service variables from travis environment Warning is unable to figure out if travis pro or free so assumes free
pub fn get_circle_env() -> Self[src]
pub fn get_jenkins_env() -> Self[src]
pub fn get_semaphore_env() -> Self[src]
pub fn get_generic_env() -> Option<Self>[src]